@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2010, 2011
+ * Copyright (C) 2010, 2011, 2013
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -91,9 +91,14 @@ extern "C" int gtatool_merge(int argc, char *argv[])
             {
                 throw exc(namei[0] + ": array has no dimension " + str::from(dimension.value()));
             }
+            bool have_input = true;
             for (size_t i = 1; i < arguments.size(); i++)
             {
-                array_loops[i].read(hdri[i], namei[i]);
+                if (!array_loops[i].read(hdri[i], namei[i]))
+                {
+                    have_input = false;
+                    break;
+                }
                 if (hdri[i].components() != hdri[0].components())
                 {
                     throw exc(namei[i] + ": incompatible array");
@@ -122,6 +127,11 @@ extern "C" int gtatool_merge(int argc, char *argv[])
                     }
                 }
             }
+            if (!have_input)
+            {
+                msg::wrn_txt("ignoring additional array(s) from %s", arguments[0].c_str());
+                break;
+            }
             gta::header hdro;
             std::string nameo;
             hdro.global_taglist() = hdri[0].global_taglist();
@@ -164,27 +174,29 @@ extern "C" int gtatool_merge(int argc, char *argv[])
                 hdro.component_taglist(c) = hdri[0].component_taglist(c);
             }
             array_loops[0].write(hdro, nameo);
-            blob element_buf(checked_cast<size_t>(hdro.element_size()));
-            std::vector<uintmax_t> indices(hdro.dimensions());
-            std::vector<element_loop_t> element_loops(arguments.size());
-            for (size_t i = 0; i < element_loops.size(); i++)
+            if (hdro.data_size() > 0)
             {
-                array_loops[i].start_element_loop(element_loops[i], hdri[i], hdro);
-            }
-            for (uintmax_t e = 0; e < hdro.elements(); e++)
-            {
-                hdro.linear_index_to_indices(e, &(indices[0]));
-                uintmax_t dim = 0;
-                size_t j;
-                for (j = 0; j < arguments.size(); j++)
+                std::vector<uintmax_t> indices(hdro.dimensions());
+                std::vector<element_loop_t> element_loops(arguments.size());
+                for (size_t i = 0; i < element_loops.size(); i++)
                 {
-                    dim += hdri[j].dimension_size(dimension.value());
-                    if (indices[dimension.value()] < dim)
+                    array_loops[i].start_element_loop(element_loops[i], hdri[i], hdro);
+                }
+                for (uintmax_t e = 0; e < hdro.elements(); e++)
+                {
+                    hdro.linear_index_to_indices(e, &(indices[0]));
+                    uintmax_t dim = 0;
+                    size_t j;
+                    for (j = 0; j < arguments.size(); j++)
                     {
-                        break;
+                        dim += hdri[j].dimension_size(dimension.value());
+                        if (indices[dimension.value()] < dim)
+                        {
+                            break;
+                        }
                     }
+                    element_loops[0].write(element_loops[j].read());
                 }
-                element_loops[0].write(element_loops[j].read());
             }
         }
         array_loops[0].finish();
